@@ -12,15 +12,15 @@ my $grammar = Marpa::R2::Grammar->new( {
     ],
 });
 $grammar->precompute;
+
 my $recognizer = Marpa::R2::Recognizer->new( { grammar => $grammar } );
 my $lexer = MarpaX::Repa::Lexer->new(
-    recognizer => $recognizer,
     tokens => {},
     debug => 1,
 );
 
 use Data::Dumper;
-print Dumper( $lexer->recognize(\*DATA)->value );
+print Dumper( $lexer->recognize( $recognizer => \*DATA)->value );
 
 __DATA__
 hello !world "he hehe hee" ( foo OR boo )
